==> qtjambi-datavisualization-6.6.1-sources.jar: io/qt/datavis/QSurfaceDataRow.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QSurfaceDataRow</a></code></p>
 */
public class QSurfaceDataRow extends io.qt.core.QList<io.qt.datavis.@NonNull QSurfaceDataItem>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QSurfaceDataRow::<wbr/>QSurfaceDataRow()</code></p>
     */
    public QSurfaceDataRow(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSurfaceDataRow instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSurfaceDataRow(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QSurfaceDataRow)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QSurfaceDataRow clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QSurfaceDataRow clone_native(long __this_nativeId);
}

==> qtjambi-datavisualization-6.6.3-sources.jar: io/qt/datavis/QSurfaceDataRow.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QSurfaceDataRow</a></code></p>
 */
public class QSurfaceDataRow extends io.qt.core.QList<io.qt.datavis.@NonNull QSurfaceDataItem>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QSurfaceDataRow::<wbr/>QSurfaceDataRow()</code></p>
     */
    public QSurfaceDataRow(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSurfaceDataRow instance);
    
    /**
     * <p>See <code>QSurfaceDataRow::<wbr/>QSurfaceDataRow(QSurfaceDataRow)</code></p>
     */
    public QSurfaceDataRow(io.qt.datavis.@StrictNonNull QSurfaceDataRow other){
        super((QPrivateConstructor)null);
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QSurfaceDataRow instance, io.qt.datavis.QSurfaceDataRow other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSurfaceDataRow(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QSurfaceDataRow::<wbr/>QSurfaceDataRow(QSurfaceDataRow)</code></p>
     */
    @QtUninvokable
    @Override
    public QSurfaceDataRow clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QSurfaceDataRow clone_native(long __this_nativeId);
}
